@@ -16,7 +16,6 @@ import torch.optim as optim
 import torch.utils.data
 import torch.utils.data.distributed
 import torch.utils.tensorboard as tensorboard
-import torchcsprng as prng
 import torchvision.models as models
 import torchvision.transforms as transforms
 from opacus import PrivacyEngine
@@ -62,13 +61,13 @@ def train(args, model, train_loader, optimizer, epoch, device):
         stats.update(stats.StatType.TRAIN, acc1=acc1)
 
         # compute gradient and do SGD step
-        optimizer.zero_grad()
         loss.backward()
 
         # make sure we take a step after processing the last mini-batch in the
         # epoch to ensure we start the next epoch with a clean state
         if ((i + 1) % args.n_accumulation_steps == 0) or ((i + 1) == len(train_loader)):
             optimizer.step()
+            optimizer.zero_grad()
         else:
             optimizer.virtual_step()
 
@@ -271,6 +270,9 @@ def main():
 
     args = parser.parse_args()
 
+    if args.disable_dp and args.n_accumulation_steps > 1:
+        raise ValueError("Virtual steps only works with enabled DP")
+
     # The following few lines, enable stats gathering about the run
     # 1. where the stats should be logged
     stats.set_global_summary_writer(
@@ -294,9 +296,21 @@ def main():
     # and set a default of per layer clipping for the Privacy Engine
     clipping = {"clip_per_layer": False, "enable_stat": True}
 
-    generator = (
-        prng.create_random_device_generator("/dev/urandom") if args.secure_rng else None
-    )
+    if args.secure_rng:
+        try:
+            import torchcsprng as prng
+        except ImportError as e:
+            msg = (
+                "To use secure RNG, you must install the torchcsprng package! "
+                "Check out the instructions here: https://github.com/pytorch/csprng#installation"
+            )
+            raise ImportError(msg) from e
+
+        generator = prng.create_random_device_generator("/dev/urandom")
+
+    else:
+        generator = None
+
     augmentations = [
         transforms.RandomCrop(32, padding=4),
         transforms.RandomHorizontalFlip(),
