@@ -13,7 +13,6 @@ import torch
 import torch.nn as nn
 import torch.nn.functional as F
 import torch.optim as optim
-import torchcsprng as prng
 from opacus import PrivacyEngine
 from torchvision import datasets, transforms
 from tqdm import tqdm
@@ -197,9 +196,20 @@ def main():
 
     kwargs = {"num_workers": 1, "pin_memory": True}
 
-    generator = (
-        prng.create_random_device_generator("/dev/urandom") if args.secure_rng else None
-    )
+    if args.secure_rng:
+        try:
+            import torchcsprng as prng
+        except ImportError as e:
+            msg = (
+                "To use secure RNG, you must install the torchcsprng package! "
+                "Check out the instructions here: https://github.com/pytorch/csprng#installation"
+            )
+            raise ImportError(msg) from e
+
+        generator = prng.create_random_device_generator("/dev/urandom")
+
+    else:
+        generator = None
 
     train_loader = torch.utils.data.DataLoader(
         datasets.MNIST(
